summaryrefslogtreecommitdiff
path: root/src/VBox/Main/src-all
diff options
context:
space:
mode:
authorvboxsync <vboxsync@cfe28804-0f27-0410-a406-dd0f0b0b656f>2016-08-08 11:12:33 +0000
committervboxsync <vboxsync@cfe28804-0f27-0410-a406-dd0f0b0b656f>2016-08-08 11:12:33 +0000
commitcbfa92e474c1885c272d3dbcf8f378a83b6b321c (patch)
tree549f114d518db1f6b9ea9bb98318e1400d2966dd /src/VBox/Main/src-all
parent92d5f92156804eacbb2a779ce0098f16fe680078 (diff)
downloadVirtualBox-svn-cbfa92e474c1885c272d3dbcf8f378a83b6b321c.tar.gz
Main: warnings
git-svn-id: https://www.virtualbox.org/svn/vbox/trunk@63147 cfe28804-0f27-0410-a406-dd0f0b0b656f
Diffstat (limited to 'src/VBox/Main/src-all')
-rw-r--r--src/VBox/Main/src-all/ExtPackManagerImpl.cpp15
-rw-r--r--src/VBox/Main/src-all/VirtualBoxBase.cpp2
2 files changed, 9 insertions, 8 deletions
diff --git a/src/VBox/Main/src-all/VirtualBoxBase.cpp b/src/VBox/Main/src-all/VirtualBoxBase.cpp
index 9f7f3de11a4..0735bb84859 100644
--- a/src/VBox/Main/src-all/VirtualBoxBase.cpp
+++ b/src/VBox/Main/src-all/VirtualBoxBase.cpp
@@ -252,9 +252,11 @@ HRESULT VirtualBoxBase::handleUnexpectedExceptions(VirtualBoxBase *const aThis,
true /* aLogIt */);
}
+#ifndef _MSC_VER /* (unreachable) */
/* should not get here */
AssertFailed();
return E_FAIL;
+#endif
}
/**
diff --git a/src/VBox/Main/src-all/ExtPackManagerImpl.cpp b/src/VBox/Main/src-all/ExtPackManagerImpl.cpp
index 177c4f031af..88b0d5eba24 100644
--- a/src/VBox/Main/src-all/ExtPackManagerImpl.cpp
+++ b/src/VBox/Main/src-all/ExtPackManagerImpl.cpp
@@ -1611,8 +1611,8 @@ ExtPack::i_hlpLoadHGCMService(PCVBOXEXTPACKHLP pHlp, VBOXEXTPACK_IF_CS(IConsole)
return pCon->i_hgcmLoadService(pszServiceLibrary, pszServiceName);
#else
NOREF(pHlp); NOREF(pConsole); NOREF(pszServiceLibrary); NOREF(pszServiceName);
-#endif
return VERR_INVALID_STATE;
+#endif
}
/*static*/ DECLCALLBACK(int)
@@ -1636,8 +1636,8 @@ ExtPack::i_hlpLoadVDPlugin(PCVBOXEXTPACKHLP pHlp, VBOXEXTPACK_IF_CS(IVirtualBox)
return pVBox->i_loadVDPlugin(pszPluginLibrary);
#else
NOREF(pHlp); NOREF(pVirtualBox);
-#endif
return VERR_INVALID_STATE;
+#endif
}
/*static*/ DECLCALLBACK(int)
@@ -1661,8 +1661,8 @@ ExtPack::i_hlpUnloadVDPlugin(PCVBOXEXTPACKHLP pHlp, VBOXEXTPACK_IF_CS(IVirtualBo
return pVBox->i_unloadVDPlugin(pszPluginLibrary);
#else
NOREF(pHlp); NOREF(pVirtualBox);
-#endif
return VERR_INVALID_STATE;
+#endif
}
/*static*/ DECLCALLBACK(int)
@@ -3040,11 +3040,10 @@ int ExtPackManager::i_getVrdeLibraryPathForExtPack(Utf8Str const *a_pstrExtPack,
* @returns S_OK if a path is returned, COM error status and message return if
* not.
* @param a_pszModuleName The library.
* @param a_pstrExtPack The extension pack.
* @param a_pstrVrdeLibrary Where to return the path.
*/
-HRESULT ExtPackManager::i_getLibraryPathForExtPack(const char *a_pszModuleName, Utf8Str const *a_pstrExtPack,
- Utf8Str *a_pstrLibrary)
+HRESULT ExtPackManager::i_getLibraryPathForExtPack(const char *a_pszModuleName, const const *a_pszExtPack, Utf8Str *a_pstrLibrary)
{
AutoCaller autoCaller(this);
HRESULT hrc = autoCaller.rc();
@@ -3052,11 +3051,11 @@ HRESULT ExtPackManager::i_getLibraryPathForExtPack(const char *a_pszModuleName,
{
AutoReadLock autoLock(this COMMA_LOCKVAL_SRC_POS);
- ExtPack *pExtPack = i_findExtPack(a_pstrExtPack->c_str());
+ ExtPack *pExtPack = i_findExtPack(a_pszExtPack);
if (pExtPack)
hrc = pExtPack->i_getLibraryName(a_pszModuleName, a_pstrLibrary);
else
- hrc = setError(VBOX_E_OBJECT_NOT_FOUND, tr("No extension pack by the name '%s' was found"), a_pstrExtPack->c_str());
+ hrc = setError(VBOX_E_OBJECT_NOT_FOUND, tr("No extension pack by the name '%s' was found"), a_pszExtPack);
}
return hrc;
@@ -3040,11 +3040,10 @@ int ExtPackManager::i_getVrdeLibraryPathForExtPack(Utf8Str const *a_pstrExtPack,
* not.
* @param a_pszModuleName The library.
- * @param a_pstrExtPack The extension pack.
+ * @param a_pszExtPack The extension pack.
* @param a_pstrVrdeLibrary Where to return the path.
*/